/*!
 * createImage.js
 * author: Brent M. Dingle
 * last modified: 2015
 * Example script to illustrate for-loop and image rotation
 *
 */
 
// ----------------------------------------------------------------------------
// ----------------------------------------------------------------------------
// theProgram (singleton) Object                            theProgram Object
// ----------------------------------------------------------------------------
// ----------------------------------------------------------------------------
var theProgram = 
{
    // ------------------------------------------------------------------------
    // Main method/function
    // Initializes global variables, runs main program
    // Call this on window load --> theProgram.Main()
    // ------------------------------------------------------------------------
    Main: function() 
    {
        // "myCanvas" refers to the canvas id="myCanvas" seen in the body section of the HTML document
        theCanvas = document.getElementById("myCanvas");
        ctx = theCanvas.getContext("2d");
        
        // Get the size of the canvas as declared in the HTML
        var width = theCanvas.width;
        var height = theCanvas.height;
        
        // Create an array of pixels the same size as the canvas
        imageData = ctx.createImageData(width, height);
        
        // Note the following
        // imageData.width   // = width of the image data in PIXELS
        // imageData.height  // = height of the image daa in PIXELS
        // imageData.data    // = pixel data array of (width * height * 4) elements
        
        // Draw random dots
        for (var i = 0; i < 15000; i++)  // 15000 is arbitrary
        {
            var x = Math.random() * width | 0;   // |0 to truncate to Int32 value
            var y = Math.random() * height | 0;
            var r = Math.random() * 256 | 0;
            var g = Math.random() * 256 | 0;
            var b = Math.random() * 256 | 0;
            theProgram.SetPixel(imageData, x, y, r, g, b, 255);  // 255 is opaque
        }
        
        // Put the image data onto the canvas
        ctx.putImageData(imageData, 0, 0);   // place data starting at upper left corner => (0, 0)
    },
    
    // ------------------------------------------------------------------------
    // SetPixel
    // (x, y) is image coordinate
    // r = red, g = green, b = blue, a = alpha 
    // for alpha --> 255 is opaque and 0 is transparent
    // ------------------------------------------------------------------------
    SetPixel: function(imageData, x, y, r, g, b, a)
    {
        var index = (x + y * imageData.width) * 4;
        imageData.data[index + 0] = r;
        imageData.data[index + 1] = g;
        imageData.data[index + 2] = b;
        imageData.data[index + 3] = a;
    },
    
};  // end theProgram variable

// ----------------------------------------------------------------------------
//                                                          window.ONLOAD
// ----------------------------------------------------------------------------
window.onload = function()
{
    //console.log("DEBUG: window.onload entered");

    // Initialize and Start the game
    theProgram.Main();
};

// ----------------------------------------------------------------------------
// ----------------------------------------------------------------------------
// end of file
    